@@ -2,6 +2,7 @@ use crate::interactive::path_of;
 use dua::traverse::{EntryData, Tree, TreeIndex};
 use itertools::Itertools;
 use petgraph::Direction;
+use std::cmp::Ordering;
 use unicode_segmentation::UnicodeSegmentation;
 
 #[derive(Default, Debug, Copy, Clone, PartialOrd, PartialEq, Eq)]
@@ -9,8 +10,10 @@ pub enum SortMode {
     #[default]
     SizeDescending,
     SizeAscending,
-    MTimeAscending,
     MTimeDescending,
+    MTimeAscending,
+    CountDescending,
+    CountAscending,
 }
 
 impl SortMode {
@@ -19,18 +22,25 @@ impl SortMode {
         *self = match self {
             SizeDescending => SizeAscending,
             SizeAscending => SizeDescending,
-            MTimeAscending => SizeAscending,
-            MTimeDescending => SizeDescending,
+            _ => SizeDescending,
         }
     }
 
     pub fn toggle_mtime(&mut self) {
         use SortMode::*;
         *self = match self {
-            SizeDescending => MTimeDescending,
-            SizeAscending => MTimeAscending,
             MTimeAscending => MTimeDescending,
             MTimeDescending => MTimeAscending,
+            _ => MTimeDescending,
+        }
+    }
+
+    pub fn toggle_count(&mut self) {
+        use SortMode::*;
+        *self = match self {
+            CountAscending => CountDescending,
+            CountDescending => CountAscending,
+            _ => CountDescending,
         }
     }
 }
@@ -44,6 +54,12 @@ pub struct EntryDataBundle {
 
 pub fn sorted_entries(tree: &Tree, node_idx: TreeIndex, sorting: SortMode) -> Vec<EntryDataBundle> {
     use SortMode::*;
+    fn cmp_count(l: &EntryDataBundle, r: &EntryDataBundle) -> Ordering {
+        l.data
+            .entry_count
+            .cmp(&r.data.entry_count)
+            .then_with(|| l.data.name.cmp(&r.data.name))
+    }
     tree.neighbors_directed(node_idx, Direction::Outgoing)
         .filter_map(|idx| {
             tree.node_weight(idx).map(|w| {
@@ -62,6 +78,8 @@ pub fn sorted_entries(tree: &Tree, node_idx: TreeIndex, sorting: SortMode) -> Ve
             SizeAscending => l.data.size.cmp(&r.data.size),
             MTimeAscending => l.data.mtime.cmp(&r.data.mtime),
             MTimeDescending => r.data.mtime.cmp(&l.data.mtime),
+            CountAscending => cmp_count(l, r),
+            CountDescending => cmp_count(l, r).reverse(),
         })
         .collect()
 }
