@@ -84,7 +84,7 @@ impl AppState {
                     .bookmarks
                     .get(&parent_idx)
                     .copied()
-                    .or_else(|| self.entries.get(0).map(|b| b.index));
+                    .or_else(|| self.entries.first().map(|b| b.index));
             }
             None => self.message = Some("Top level reached".into()),
         }
@@ -161,6 +161,11 @@ impl AppState {
         self.entries = sorted_entries(&traversal.tree, self.root, self.sorting);
     }
 
+    pub fn cycle_count_sorting(&mut self, traversal: &Traversal) {
+        self.sorting.toggle_count();
+        self.entries = sorted_entries(&traversal.tree, self.root, self.sorting);
+    }
+
     pub fn reset_message(&mut self) {
         if self.is_scanning {
             self.message = Some("-> scanning <-".into());
@@ -321,7 +326,7 @@ impl AppState {
             .and_then(|selected| self.entries.iter().find(|e| e.index == selected))
             .is_none()
         {
-            self.selected = self.entries.get(0).map(|e| e.index);
+            self.selected = self.entries.first().map(|e| e.index);
         }
         self.recompute_sizes_recursively(parent_idx, traversal);
         entries_deleted
