@@ -1,3 +1,4 @@
+use crate::interactive::widgets::COUNT;
 use crate::interactive::{
     path_of,
     widgets::{entry_color, EntryMarkMap},
@@ -5,7 +6,6 @@ use crate::interactive::{
 };
 use chrono::DateTime;
 use dua::traverse::{EntryData, Tree, TreeIndex};
-use human_format;
 use itertools::Itertools;
 use std::time::SystemTime;
 use std::{borrow::Borrow, path::Path};
@@ -67,7 +67,12 @@ impl Entries {
         };
 
         let total: u128 = entries.iter().map(|b| b.data.size).sum();
-        let title = title(&current_path(tree, *root), entries.len());
+        let (item_count, item_size): (u64, u128) = entries
+            .iter()
+            .map(|f| (f.data.entry_count.unwrap_or(1), f.data.size))
+            .reduce(|a, b| (a.0 + b.0, a.1 + b.1))
+            .unwrap_or_default();
+        let title = title(&current_path(tree, *root), item_count, *display, item_size);
         let title_block = title_block(&title, *border_style);
         let entry_in_view = entry_in_view(*selected, entries);
 
@@ -149,15 +154,16 @@ fn title_block(title: &str, border_style: Style) -> Block<'_> {
         .borders(Borders::ALL)
 }
 
-fn title(current_path: &str, item_count: usize) -> String {
+fn title(current_path: &str, item_count: u64, display: DisplayOptions, size: u128) -> String {
     format!(
-        " {} ({} item{}) ",
+        " {} ({} item{}, {}) ",
         current_path,
-        item_count,
+        COUNT.format(item_count as f64),
         match item_count {
             1 => "",
             _ => "s",
-        }
+        },
+        display.byte_format.display(size)
     )
 }
 
@@ -250,10 +256,7 @@ fn count_column(entry_count: Option<u64>, style: Style) -> Span<'static> {
             "{:>4}",
             match entry_count {
                 Some(count) => {
-                    human_format::Formatter::new()
-                        .with_decimals(0)
-                        .with_separator("")
-                        .format(count as f64)
+                    COUNT.format(count as f64)
                 }
                 None => "".to_string(),
             }
